@@ -3,20 +3,13 @@
 import threading
 import time
 import math
-from numba import jit
 from datetime import datetime
-from pymodbus.payload import BinaryPayloadDecoder
-from pymodbus.constants import Endian
 # Import pymodbus for the Modbus RTU Module
 from pymodbus.client.sync import ModbusSerialClient as ModbusClient
 lock = threading.Lock()
 filename = 'error.txt'
 
 
-
-
-
-
 def splitBytes(list16bit):
     # Function to split a list with 16 bit elements into 8 bit element list
     list8bit = []
